drop_csquares: Drop c-square information from object

View source: R/drop.R

drop_csquaresR Documentation

Drop c-square information from object

Description

Drops c-square data from an object, but keeps the parent class of the object intact. You cannot deselect the csquare column from a csquares object as this will render the object invalid. Use drop_csquares instead.

Usage

drop_csquares(x, ...)

Arguments

x

An object of class csquares from which the c-square information needs to be dropped.

...

ignored

Value

Returns a copy of x inheriting its parent classes but with out csquares info.

Author(s)

Pepijn de Vries

Examples

csq <- as_csquares("1000")
drop_csquares(csq)

csq <-
  data.frame(csquares = "1000", foo = "bar") |>
  as_csquares(csquares = "csquares")

drop_csquares(csq)

csquares documentation built on Sept. 11, 2024, 7:21 p.m.