| expand_wildcards | R Documentation |
The asterisk (*) can be used as a wildcard, for a compact
notation of csquares. expand_wildcards will replace all
wild cards with valid combinations of values and expands
the compact notation to an explicit notation without
wildcards.
Check out vignette("wildcards") for more details.
expand_wildcards(x, csquares, ...)
x |
A |
csquares |
When |
... |
ignored |
Returns a csquares object with full notation
Pepijn de Vries
expand_wildcards("1000:*")
expand_wildcards("1000:***")
expand_wildcards("1000:1**")
expand_wildcards("1000:***:*")
expand_wildcards(c("1000:*", "1000:***", "1000:1**", "1000:***:*"))
expand_wildcards(data.frame(csq = "1000:*", foo = "bar"), csquares = "csq")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.