orca: Killer whale realm

orcaR Documentation

Killer whale realm

Description

Killer whale realm

Usage

orca

Format

orca

The orca object is a Killer whale realm data set extracted from the data as provided by Costello (2017) and published by Costello et al. (2017). It is a data frame with 2,058 rows and two columns:

csquares

c-squares codes indicating spatial grid cells

orcinus_orca

logical values indicating whether the corresponding c-squares grid cell belongs to the killer whales (Orcinus orca) biogeographic realm or not.

References

  • Costello, M.J. (2017); University of Auckland \Sexpr[results=rd]{tools:::Rd_expr_doi("10.17608/k6.auckland.5086654")} Licence CC BY 4.0

  • Costello M.J., Tsai P., Wong P.S., Cheung A.K.L, Basher Z. & Chaudhary C. (2017); "Marine biogeographic realms and species endemicity" Nature Communications 8, 1057 \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1038/s41467-017-01121-2")}


csquares documentation built on Sept. 11, 2024, 7:21 p.m.