validate_csquares: Test if a csquares object is valid

View source: R/validate.R

validate_csquaresR Documentation

Test if a csquares object is valid

Description

Tests if a csquares object is correctly specified and can be translated into valid coordinates

Usage

validate_csquares(x)

Arguments

x

An object of class csquares to be evaluated.

Value

Returns a logical value indicating whether the csquares object is valid or not.

Author(s)

Pepijn de Vries

Examples

validate_csquares(
  as_csquares("7500:110:3|7500:110:1|1500:110:3|1500:110:1")
)

csquares documentation built on Sept. 11, 2024, 7:21 p.m.