| drop_csquares | R Documentation |
Drops c-square data from an object, but keeps the parent class of the object
intact. You cannot deselect the csquare column from a csquares object as this
will render the object invalid. Use drop_csquares instead.
drop_csquares(x, ...)
x |
An object of class |
... |
ignored |
Returns a copy of x inheriting its parent classes but with out
csquares info.
Pepijn de Vries
csq <- as_csquares("1000")
drop_csquares(csq)
csq <-
data.frame(csquares = "1000", foo = "bar") |>
as_csquares(csquares = "csquares")
drop_csquares(csq)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.