| validate_csquares | R Documentation |
Tests if a csquares object is correctly specified and can be translated into valid coordinates
validate_csquares(x)
x |
An object of class |
Returns a logical value indicating whether the csquares object is valid or not.
Pepijn de Vries
validate_csquares(
as_csquares("7500:110:3|7500:110:1|1500:110:3|1500:110:1")
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.